'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var NextLink = require('next/link');
var navigation = require('next/navigation');
var React = require('react');
var router = require('next/router');
var useIntl = require('use-intl');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var NextLink__default = /*#__PURE__*/_interopDefaultLegacy(NextLink);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function localizePathname(locale, pathname) {
  var localizedHref = '/' + locale;

  if (pathname !== '/') {
    localizedHref += pathname;
  }

  return localizedHref;
}

// Reuse the legacy cookie name
// https://nextjs.org/docs/advanced-features/i18n-routing#leveraging-the-next_locale-cookie
var COOKIE_LOCALE_NAME = 'NEXT_LOCALE'; // Should take precedence over the cookie

function getCookieValueByName(name) {
  // https://stackoverflow.com/a/15724300/343045
  var value = "; " + document.cookie;
  var parts = value.split("; " + name + "=");

  if (parts.length === 2) {
    var _parts$pop;

    var part = (_parts$pop = parts.pop()) == null ? void 0 : _parts$pop.split(';').shift();
    if (part) return part;
  }

  throw new Error("Unable to find next-intl cookie, have you configured the middleware?");
}

function getCookieLocale() {
  return getCookieValueByName(COOKIE_LOCALE_NAME);
}

function hasPathnamePrefixed(locale, pathname) {
  var prefix = "/" + locale;
  return pathname === prefix || pathname.startsWith(prefix + "/") && pathname.length > prefix.length;
}

function localizeHref(href, locale) {
  var cookieLocale = getCookieLocale();
  if (!locale) locale = cookieLocale;
  var pathname = window.location.pathname;
  var isSwitchingLocale = locale !== cookieLocale;
  var isPathnamePrefixed = hasPathnamePrefixed(locale, pathname);

  if (isPathnamePrefixed || isSwitchingLocale) {
    var prefixedHref;

    if (typeof href === 'string') {
      prefixedHref = localizePathname(locale, href);
    } else {
      prefixedHref = _extends({}, href);

      if (href.pathname) {
        prefixedHref.pathname = localizePathname(locale, href.pathname);
      }
    }

    return prefixedHref;
  } else {
    return href;
  }
}

var _excluded$1 = ["href", "locale", "prefetch"];
/**
 * Wraps `next/link` and prefixes the `href` with the current locale.
 */

function Link(_ref, ref) {
  var href = _ref.href,
      locale = _ref.locale,
      prefetch = _ref.prefetch,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  var _useState = React.useState(href),
      localizedHref = _useState[0],
      setLocalizedHref = _useState[1];

  var pathname = navigation.usePathname(); // When the user renders a link to another locale, Next.js might prefetch it
  // and the `set-cookie` response header will cause the locale cookie on the
  // current page to be overwritten. Therefore default to disabling prefetching
  // when the user passes a `locale` prop.

  if (prefetch === undefined && locale !== undefined) {
    prefetch = false;
  }

  React.useEffect(function () {
    setLocalizedHref(localizeHref(href, locale));
  }, [href, locale, pathname]);
  return React__default["default"].createElement(NextLink__default["default"], _extends({
    ref: ref,
    href: localizedHref,
    prefetch: prefetch
  }, rest));
}

var Link$1 = /*#__PURE__*/React.forwardRef(Link);

var _excluded = ["children", "locale", "now"];

function NextIntlClientProvider(_ref) {
  var children = _ref.children,
      locale = _ref.locale,
      now = _ref.now,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var router$1;

  try {
    // Reading from context is practically ok to do conditionally
    // eslint-disable-next-line react-hooks/rules-of-hooks
    router$1 = router.useRouter();
  } catch (error) {// Calling `useRouter` is not supported in the app folder
  } // The router can be undefined if used in a context outside
  // of Next.js (e.g. unit tests, Storybook, ...)


  if (!locale && router$1) {
    locale = router$1.locale;
  } // Currently RSC serialize dates to strings, therefore make sure we have
  // a date object. We might be able to remove this once more types have
  // first-class serialization support (https://github.com/facebook/react/issues/25687)


  if (typeof now === 'string') {
    now = new Date(now);
  }

  if (!locale) {
    throw new Error("Couldn't determine locale. Please pass an explicit `locale` prop the provider, or if you're using the `pages` folder, use internationalized routing (https://nextjs.org/docs/advanced-features/i18n-routing)." );
  }

  return React__default["default"].createElement(useIntl.IntlProvider, _extends({
    locale: locale,
    now: now
  }, rest), children);
}

function useRouter() {
  var router = navigation.useRouter();
  return React.useMemo(function () {
    return _extends({}, router, {
      push: function push(href) {
        return router.push(localizeHref(href));
      },
      replace: function replace(href) {
        return router.replace(localizeHref(href));
      },
      prefetch: function prefetch(href) {
        return router.prefetch(localizeHref(href));
      }
    });
  }, [router]);
}

// during the beta, remove for stable release

var hasWarned = false;
function useLocalizedRouterDeprecated() {
  if (!hasWarned) {
    console.warn("\n\nDEPRECATION WARNING: The `useLocalizedRouter` import from `next-intl` is deprecated and will be removed in the stable release of next-intl. Please import `useLocalizedRouter` from `next-intl/client` instead. See https://next-intl-docs.vercel.app/docs/next-13/server-components\n\n");
    hasWarned = true;
  }

  return useRouter();
}

/**
 * This is the main entry file when non-'react-server' environments import
 * from 'next-intl'. Make sure this mirrors the API from 'react-server'.
 */
/** @deprecated Is called `NextIntlClientProvider` now. */

var NextIntlProvider = NextIntlClientProvider;
/** @deprecated Is called `Link` now. */

var LocalizedLink = Link$1;

exports.Link = Link$1;
exports.LocalizedLink = LocalizedLink;
exports.NextIntlClientProvider = NextIntlClientProvider;
exports.NextIntlProvider = NextIntlProvider;
exports.useLocalizedRouter = useLocalizedRouterDeprecated;
Object.keys(useIntl).forEach(function (k) {
  if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return useIntl[k]; }
  });
});
//# sourceMappingURL=next-intl.cjs.development.js.map
