import { objectWithoutPropertiesLoose as _objectWithoutPropertiesLoose, extends as _extends } from '../_virtual/next-intl.esm.js';
import NextLink from 'next/link';
import { usePathname } from 'next/navigation';
import React, { forwardRef, useState, useEffect } from 'react';
import localizeHref from '../client/next-intl.esm2.js';

var _excluded = ["href", "locale", "prefetch"];
/**
 * Wraps `next/link` and prefixes the `href` with the current locale.
 */

function Link(_ref, ref) {
  var href = _ref.href,
      locale = _ref.locale,
      prefetch = _ref.prefetch,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useState = useState(href),
      localizedHref = _useState[0],
      setLocalizedHref = _useState[1];

  var pathname = usePathname(); // When the user renders a link to another locale, Next.js might prefetch it
  // and the `set-cookie` response header will cause the locale cookie on the
  // current page to be overwritten. Therefore default to disabling prefetching
  // when the user passes a `locale` prop.

  if (prefetch === undefined && locale !== undefined) {
    prefetch = false;
  }

  useEffect(function () {
    setLocalizedHref(localizeHref(href, locale));
  }, [href, locale, pathname]);
  return React.createElement(NextLink, _extends({
    ref: ref,
    href: localizedHref,
    prefetch: prefetch
  }, rest));
}

var Link$1 = /*#__PURE__*/forwardRef(Link);

export { Link$1 as default };
//# sourceMappingURL=next-intl.esm2.js.map
