'use client';
import Link from 'next/link';
import { usePathname } from 'next/navigation';
import React, { forwardRef, useEffect, useState } from 'react';
import localizeHref from '../client/localizeHref';
/**
 * Wraps `next/link` and prefixes the `href` with the current locale.
 */
function LocalizedLink({ href, locale, ...rest }, ref) {
    const [localizedHref, setLocalizedHref] = useState(href);
    const pathname = usePathname();
    useEffect(() => {
        setLocalizedHref(localizeHref(href, locale));
    }, [href, locale, pathname]);
    return React.createElement(Link, { ref: ref, href: localizedHref, ...rest });
}
export default forwardRef(LocalizedLink);
//# sourceMappingURL=LocalizedLink.js.map